@@ -1,13 +1,16 @@
 package Elive::Entity::Recording;
 use warnings; use strict;
+use Mouse;
 
+use Elive::Entity;
 use base qw{ Elive::Entity };
-use Moose;
 
 __PACKAGE__->entity_name('Recording');
 __PACKAGE__->collection_name('Recordings');
 
-has 'recordingId' => (is => 'rw', isa => 'PkeyStr', required => 1);
+has 'recordingId' => (is => 'rw', isa => 'Str', required => 1);
+__PACKAGE__->primary_key('recordingId');
+
 has 'creationDate' => (is => 'rw', isa => 'Int');
 has 'data' => (is => 'rw', isa => 'Str');
 has 'facilitator' => (is => 'rw', isa => 'Int', required => 1);
